<?php
/**
 * Theme customizer
 *
 * @package Bigger
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Bigger_Customize {
	/**
	 * Customize settings
	 *
	 * @var array
	 */
	protected $config = array();

	/**
	 * The class constructor
	 *
	 * @param array $config
	 */
	public function __construct( $config ) {
		$this->config = $config;

		if ( ! class_exists( 'Kirki' ) ) {
			return;
		}

		$this->register();
	}

	/**
	 * Register settings
	 */
	public function register() {

		/**
		 * Add the theme configuration
		 */
		if ( ! empty( $this->config['theme'] ) ) {
			Kirki::add_config(
				$this->config['theme'], array(
					'capability'  => 'edit_theme_options',
					'option_type' => 'theme_mod',
				)
			);
		}

		/**
		 * Add panels
		 */
		if ( ! empty( $this->config['panels'] ) ) {
			foreach ( $this->config['panels'] as $panel => $settings ) {
				Kirki::add_panel( $panel, $settings );
			}
		}

		/**
		 * Add sections
		 */
		if ( ! empty( $this->config['sections'] ) ) {
			foreach ( $this->config['sections'] as $section => $settings ) {
				Kirki::add_section( $section, $settings );
			}
		}

		/**
		 * Add fields
		 */
		if ( ! empty( $this->config['theme'] ) && ! empty( $this->config['fields'] ) ) {
			foreach ( $this->config['fields'] as $name => $settings ) {
				if ( ! isset( $settings['settings'] ) ) {
					$settings['settings'] = $name;
				}

				Kirki::add_field( $this->config['theme'], $settings );
			}
		}
	}

	/**
	 * Get config ID
	 *
	 * @return string
	 */
	public function get_theme() {
		return $this->config['theme'];
	}

	/**
	 * Get customize setting value
	 *
	 * @param string $name
	 *
	 * @return bool|string
	 */
	public function get_option( $name ) {

		$default = $this->get_option_default( $name );

		return get_theme_mod( $name, $default );
	}

	/**
	 * Get default option values
	 *
	 * @param $name
	 *
	 * @return mixed
	 */
	public function get_option_default( $name ) {
		if ( ! isset( $this->config['fields'][ $name ] ) ) {
			return false;
		}

		return isset( $this->config['fields'][ $name ]['default'] ) ? $this->config['fields'][ $name ]['default'] : false;
	}
}

/**
 * This is a short hand function for getting setting value from customizer
 *
 * @param string $name
 *
 * @return bool|string
 */
function bigger_get_option( $name ) {
	global $bigger_customize;

	$value = false;

	if ( class_exists( 'Kirki' ) ) {
		$value = Kirki::get_option( 'bigger', $name );
	} elseif ( ! empty( $bigger_customize ) ) {
		$value = $bigger_customize->get_option( $name );
	}

	return apply_filters( 'bigger_get_option', $value, $name );
}

/**
 * Get default option values
 *
 * @param $name
 *
 * @return mixed
 */
function bigger_get_option_default( $name ) {
	global $bigger_customize;

	if ( empty( $bigger_customize ) ) {
		return false;
	}

	return $bigger_customize->get_option_default( $name );
}

/**
 * Move some default sections to `general` panel that registered by theme
 *
 * @param object $wp_customize
 */
function bigger_customize_modify( $wp_customize ) {
	$wp_customize->get_section( 'title_tagline' )->panel     = 'general';
	$wp_customize->get_section( 'static_front_page' )->panel = 'general';
}

add_action( 'customize_register', 'bigger_customize_modify' );


/**
 * Get customize settings
 *
 * Priority (Order) WordPress Live Customizer default: 
 * @link https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @return array
 */
function bigger_customize_settings() {
	/**
	 * Customizer configuration
	 */

	$settings = array(
		'theme' => 'bigger',
	);

	$panels = array(
		'general'     => array(
			'priority' => 5,
			'title'    => esc_html__( 'General', 'bigger' ),
		),
        'blog'        => array(
			'title'      => esc_html__( 'Blog', 'bigger' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
	);

	$sections = array(
		'blog_page'           => array(
			'title'       => esc_html__( 'Blog Page', 'bigger' ),
			'description' => '',
			'priority'    => 9,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),
        'single_post'           => array(
			'title'       => esc_html__( 'Single Post', 'bigger' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),
		'styling'           => array(
            'title'       => esc_html__( 'Styling', 'bigger' ),
            'description' => '',
            'priority'    => 25,
            'capability'  => 'edit_theme_options',
        ),
	);

	$fields = array(
		//Shop
		'per_page'     => array(
            'type'     => 'number',
            'label'    => esc_html__( 'Product Per Page', 'bigger' ),
            'section'  => 'woocommerce_product_catalog',
            'default'  => 4,
            'priority' => 10,
            'description' => 'Enter number products display per page.',
        ),
        'loop_columns' => array(
            'type'     => 'select',
            'label'    => esc_html__( 'Product Loop Columns', 'bigger' ),
            'section'  => 'woocommerce_product_catalog',
            'default'  => 2,
            'choices'  => array(
                '2'    => esc_html__( '2 Columns', 'bigger' ),
                '3'    => esc_html__( '3 Columns', 'bigger' ),
                '4'    => esc_html__( '4 Columns', 'bigger' ),
            ),
            'priority' => 10,
            'description' => 'Choose number columns display per row.',
        ),
		//Styling
        'bg_body'      => array(
            'type'     => 'color',
            'label'    => esc_html__( 'Background Body', 'bigger' ),
            'section'  => 'styling',
            'default'  => '',
            'priority' => 10,
            'output'   => array(
                array(
                    'element'  => 'body, .site-content',
                    'property' => 'background-color',
                ),
            ),
        ),
        'main_color'   => array(
            'type'     => 'color',
            'label'    => esc_html__( 'Primary Color', 'bigger' ),
            'section'  => 'styling',
            'default'  => '#fdba2c',
            'priority' => 10,
        ),
        'second_color' => array(
            'type'     => 'color',
            'label'    => esc_html__( 'Second Color', 'bigger' ),
            'section'  => 'styling',
            'default'  => '#051f45',
            'priority' => 10,
        ),
	);
	$settings['panels']   = apply_filters( 'bigger_customize_panels', $panels );
	$settings['sections'] = apply_filters( 'bigger_customize_sections', $sections );
	$settings['fields']   = apply_filters( 'bigger_customize_fields', $fields );

	return $settings;
}

$bigger_customize = new Bigger_Customize( bigger_customize_settings() );

require get_template_directory() . '/inc/backend/customizer-blog.php';
require get_template_directory() . '/inc/backend/customizer-header.php';
require get_template_directory() . '/inc/backend/customizer-page-header.php';
require get_template_directory() . '/inc/backend/customizer-footer.php';
require get_template_directory() . '/inc/backend/customizer-typography.php';